@@ -27,7 +27,7 @@ except ImportError:
 from errno import EAGAIN, ECONNRESET
 import os
 
-__version__ = "0.1.4"
+__version__ = "0.2.0"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_HTTPServer.git"
 
 
@@ -275,6 +275,7 @@ class HTTPServer:
         self.routes = {}
         self._socket_source = socket_source
         self._sock = None
+        self.root_path = "/"
 
     def route(self, path: str, method: str = "GET"):
         """Decorator used to add a route.
@@ -302,33 +303,50 @@ class HTTPServer:
         :param int port: port
         :param str root: root directory to serve files from
         """
+        self.start(host, port, root)
+
+        while True:
+            try:
+                self.poll()
+            except OSError:
+                continue
+
+    def start(self, host: str, port: int = 80, root: str = "") -> None:
+        """
+        Start the HTTP server at the given host and port. Requires calling
+        poll() in a while loop to handle incoming requests.
+
+        :param str host: host name or IP address
+        :param int port: port
+        :param str root: root directory to serve files from
+        """
+        self.root_path = root
+
         self._sock = self._socket_source.socket(
             self._socket_source.AF_INET, self._socket_source.SOCK_STREAM
         )
         self._sock.bind((host, port))
-        self._sock.listen(1)
+        self._sock.listen(10)
 
-        while True:
-            try:
-                conn, _ = self._sock.accept()
-            except OSError:
-                continue
-            with conn:
-                # If reading fails, close connection and retry.
-                try:
-                    length, _ = conn.recvfrom_into(self._buffer)
-                except OSError:
-                    continue
+    def poll(self):
+        """
+        Call this method inside your main event loop to get the server to
+        check for new incoming client requests. When a request comes in,
+        the application callable will be invoked.
+        """
+        conn, _ = self._sock.accept()
+        with conn:
+            length, _ = conn.recvfrom_into(self._buffer)
 
-                request = _HTTPRequest(raw_request=self._buffer[:length])
+            request = _HTTPRequest(raw_request=self._buffer[:length])
 
-                # If a route exists for this request, call it. Otherwise try to serve a file.
-                route = self.routes.get(request, None)
-                if route:
-                    response = route(request)
-                elif request.method == "GET":
-                    response = HTTPResponse(filename=request.path, root=root)
-                else:
-                    response = HTTPResponse(status=HTTPStatus.INTERNAL_SERVER_ERROR)
+            # If a route exists for this request, call it. Otherwise try to serve a file.
+            route = self.routes.get(request, None)
+            if route:
+                response = route(request)
+            elif request.method == "GET":
+                response = HTTPResponse(filename=request.path, root=self.root_path)
+            else:
+                response = HTTPResponse(status=HTTPStatus.INTERNAL_SERVER_ERROR)
 
-                response.send(conn)
+            response.send(conn)
